@@ -363,9 +363,9 @@ AJAX.registerOnload('server_status_monitor.js', function () {
 
     // Server is localhost => We can add cpu/memory/swap to the default chart
     if (server_db_isLocal) {
-        defaultChartGrid['c3'] = presetCharts['cpu'];
-        defaultChartGrid['c4'] = presetCharts['memory'];
-        defaultChartGrid['c5'] = presetCharts['swap'];
+        defaultChartGrid.c3 = presetCharts.cpu;
+        defaultChartGrid.c4 = presetCharts.memory;
+        defaultChartGrid.c5 = presetCharts.swap;
     }
 
     $('a[href="#rearrangeCharts"], a[href="#endChartEditMode"]').click(function (event) {
@@ -413,18 +413,27 @@ AJAX.registerOnload('server_status_monitor.js', function () {
         var numColumns;
         var $tr = $('#chartGrid tr:first');
         var row = 0;
+
+        var tempManageCols = function () {
+            if (numColumns > monitorSettings.columns) {
+                if ($tr.next().length === 0) {
+                    $tr.after('<tr></tr>');
+                }
+                $tr.next().prepend($(this));
+            }
+            numColumns++;
+        };
+
+        var tempAddCol = function () {
+            if ($(this).next().length !== 0) {
+                $(this).append($(this).next().find('td:first'));
+            }
+        };
+
         while ($tr.length !== 0) {
             numColumns = 1;
             // To many cells in one row => put into next row
-            $tr.find('td').each(function () {
-                if (numColumns > monitorSettings.columns) {
-                    if ($tr.next().length === 0) {
-                        $tr.after('<tr></tr>');
-                    }
-                    $tr.next().prepend($(this));
-                }
-                numColumns++;
-            });
+            $tr.find('td').each(tempManageCols);
 
             // To little cells in one row => for each cell to little,
             // move all cells backwards by 1
@@ -432,11 +441,7 @@ AJAX.registerOnload('server_status_monitor.js', function () {
                 var cnt = monitorSettings.columns - $tr.find('td').length;
                 for (var i = 0; i < cnt; i++) {
                     $tr.append($tr.next().find('td:first'));
-                    $tr.nextAll().each(function () {
-                        if ($(this).next().length !== 0) {
-                            $(this).append($(this).next().find('td:first'));
-                        }
-                    });
+                    $tr.nextAll().each(tempAddCol);
                 }
             }
 
@@ -567,7 +572,7 @@ AJAX.registerOnload('server_status_monitor.js', function () {
         $('<form />', {
             "class": "disableAjax",
             method: "post",
-            action: "file_echo.php?" + PMA_commonParams.get('common_query') + "&filename=1",
+            action: "file_echo.php" + PMA_commonParams.get('common_query') + "&filename=1",
             style: "display:none;"
         })
         .append(
@@ -585,7 +590,7 @@ AJAX.registerOnload('server_status_monitor.js', function () {
     $('a[href="#importMonitorConfig"]').click(function (event) {
         event.preventDefault();
         $('#emptyDialog').dialog({title: PMA_messages.strImportDialogTitle});
-        $('#emptyDialog').html(PMA_messages.strImportDialogMessage + ':<br/><form action="file_echo.php?' + PMA_commonParams.get('common_query') + '&import=1" method="post" enctype="multipart/form-data">' +
+        $('#emptyDialog').html(PMA_messages.strImportDialogMessage + ':<br/><form action="file_echo.php' + PMA_commonParams.get('common_query') + '&import=1" method="post" enctype="multipart/form-data">' +
             '<input type="file" name="file"> <input type="hidden" name="import" value="1"> </form>');
 
         var dlgBtns = {};
@@ -621,8 +626,8 @@ AJAX.registerOnload('server_status_monitor.js', function () {
 
                 // If json ok, try applying config
                 try {
-                    window.localStorage['monitorCharts'] = JSON.stringify(json.monitorCharts);
-                    window.localStorage['monitorSettings'] = JSON.stringify(json.monitorSettings);
+                    window.localStorage.monitorCharts = JSON.stringify(json.monitorCharts);
+                    window.localStorage.monitorSettings = JSON.stringify(json.monitorSettings);
                     rebuildGrid();
                 } catch (err) {
                     alert(PMA_messages.strFailedBuildingGrid);
@@ -665,9 +670,9 @@ AJAX.registerOnload('server_status_monitor.js', function () {
         event.preventDefault();
         runtime.redrawCharts = ! runtime.redrawCharts;
         if (! runtime.redrawCharts) {
-            $(this).html(PMA_getImage('play.png') + ' ' + PMA_messages.strResumeMonitor);
+            $(this).html(PMA_getImage('play.png') + PMA_messages.strResumeMonitor);
         } else {
-            $(this).html(PMA_getImage('pause.png') + ' ' + PMA_messages.strPauseMonitor);
+            $(this).html(PMA_getImage('pause.png') + PMA_messages.strPauseMonitor);
             if (! runtime.charts) {
                 initGrid();
                 $('a[href="#settingsPopup"]').show();
@@ -692,7 +697,7 @@ AJAX.registerOnload('server_status_monitor.js', function () {
                 $.extend(vars, getvars);
             }
 
-            $.get('server_status_monitor.php?' + PMA_commonParams.get('common_query'), vars,
+            $.get('server_status_monitor.php' + PMA_commonParams.get('common_query'), vars,
                 function (data) {
                     var logVars;
                     if (typeof data !== 'undefined' && data.success === true) {
@@ -702,15 +707,15 @@ AJAX.registerOnload('server_status_monitor.js', function () {
                     }
                     var icon = PMA_getImage('s_success.png'), msg = '', str = '';
 
-                    if (logVars['general_log'] == 'ON') {
-                        if (logVars['slow_query_log'] == 'ON') {
+                    if (logVars.general_log == 'ON') {
+                        if (logVars.slow_query_log == 'ON') {
                             msg = PMA_messages.strBothLogOn;
                         } else {
                             msg = PMA_messages.strGenLogOn;
                         }
                     }
 
-                    if (msg.length === 0 && logVars['slow_query_log'] == 'ON') {
+                    if (msg.length === 0 && logVars.slow_query_log == 'ON') {
                         msg = PMA_messages.strSlowLogOn;
                     }
 
@@ -722,22 +727,22 @@ AJAX.registerOnload('server_status_monitor.js', function () {
                     str = '<b>' + PMA_messages.strCurrentSettings + '</b><br/><div class="smallIndent">';
                     str += icon + msg + '<br />';
 
-                    if (logVars['log_output'] != 'TABLE') {
+                    if (logVars.log_output != 'TABLE') {
                         str += PMA_getImage('s_error.png') + ' ' + PMA_messages.strLogOutNotTable + '<br />';
                     } else {
                         str += PMA_getImage('s_success.png') + ' ' + PMA_messages.strLogOutIsTable + '<br />';
                     }
 
-                    if (logVars['slow_query_log'] == 'ON') {
-                        if (logVars['long_query_time'] > 2) {
+                    if (logVars.slow_query_log == 'ON') {
+                        if (logVars.long_query_time > 2) {
                             str += PMA_getImage('s_attention.png') + ' ';
-                            str += $.sprintf(PMA_messages.strSmallerLongQueryTimeAdvice, logVars['long_query_time']);
+                            str += PMA_sprintf(PMA_messages.strSmallerLongQueryTimeAdvice, logVars.long_query_time);
                             str += '<br />';
                         }
 
-                        if (logVars['long_query_time'] < 2) {
+                        if (logVars.long_query_time < 2) {
                             str += PMA_getImage('s_success.png') + ' ';
-                            str += $.sprintf(PMA_messages.strLongQueryTimeSet, logVars['long_query_time']);
+                            str += PMA_sprintf(PMA_messages.strLongQueryTimeSet, logVars.long_query_time);
                             str += '<br />';
                         }
                     }
@@ -750,41 +755,41 @@ AJAX.registerOnload('server_status_monitor.js', function () {
                         str += PMA_messages.strSettingsAppliedGlobal + '<br/>';
 
                         var varValue = 'TABLE';
-                        if (logVars['log_output'] == 'TABLE') {
+                        if (logVars.log_output == 'TABLE') {
                             varValue = 'FILE';
                         }
 
                         str += '- <a class="set" href="#log_output-' + varValue + '">';
-                        str += $.sprintf(PMA_messages.strSetLogOutput, varValue);
+                        str += PMA_sprintf(PMA_messages.strSetLogOutput, varValue);
                         str += ' </a><br />';
 
-                        if (logVars['general_log'] != 'ON') {
+                        if (logVars.general_log != 'ON') {
                             str += '- <a class="set" href="#general_log-ON">';
-                            str += $.sprintf(PMA_messages.strEnableVar, 'general_log');
+                            str += PMA_sprintf(PMA_messages.strEnableVar, 'general_log');
                             str += ' </a><br />';
                         } else {
                             str += '- <a class="set" href="#general_log-OFF">';
-                            str += $.sprintf(PMA_messages.strDisableVar, 'general_log');
+                            str += PMA_sprintf(PMA_messages.strDisableVar, 'general_log');
                             str += ' </a><br />';
                         }
 
-                        if (logVars['slow_query_log'] != 'ON') {
+                        if (logVars.slow_query_log != 'ON') {
                             str += '- <a class="set" href="#slow_query_log-ON">';
-                            str +=  $.sprintf(PMA_messages.strEnableVar, 'slow_query_log');
+                            str +=  PMA_sprintf(PMA_messages.strEnableVar, 'slow_query_log');
                             str += ' </a><br />';
                         } else {
                             str += '- <a class="set" href="#slow_query_log-OFF">';
-                            str +=  $.sprintf(PMA_messages.strDisableVar, 'slow_query_log');
+                            str +=  PMA_sprintf(PMA_messages.strDisableVar, 'slow_query_log');
                             str += ' </a><br />';
                         }
 
                         varValue = 5;
-                        if (logVars['long_query_time'] > 2) {
+                        if (logVars.long_query_time > 2) {
                             varValue = 1;
                         }
 
                         str += '- <a class="set" href="#long_query_time-' + varValue + '">';
-                        str += $.sprintf(PMA_messages.setSetLongQueryTime, varValue);
+                        str += PMA_sprintf(PMA_messages.setSetLongQueryTime, varValue);
                         str += ' </a><br />';
 
                     } else {
@@ -794,7 +799,7 @@ AJAX.registerOnload('server_status_monitor.js', function () {
                     str += '</div>';
 
                     $dialog.find('div.monitorUse').toggle(
-                        logVars['log_output'] == 'TABLE' && (logVars['slow_query_log'] == 'ON' || logVars['general_log'] == 'ON')
+                        logVars.log_output == 'TABLE' && (logVars.slow_query_log == 'ON' || logVars.general_log == 'ON')
                     );
 
                     $dialog.find('div.ajaxContent').html(str);
@@ -901,7 +906,7 @@ AJAX.registerOnload('server_status_monitor.js', function () {
         }
 
         var str = serie.display == 'differential' ? ', ' + PMA_messages.strDifferential : '';
-        str += serie.valueDivisor ? (', ' + $.sprintf(PMA_messages.strDividedBy, serie.valueDivisor)) : '';
+        str += serie.valueDivisor ? (', ' + PMA_sprintf(PMA_messages.strDividedBy, serie.valueDivisor)) : '';
         str += serie.unit ? (', ' + PMA_messages.strUnit + ': ' + serie.unit) : '';
 
         var newSeries = {
@@ -934,16 +939,16 @@ AJAX.registerOnload('server_status_monitor.js', function () {
 
         /* Apply default values & config */
         if (window.localStorage) {
-            if (window.localStorage['monitorCharts']) {
-                runtime.charts = $.parseJSON(window.localStorage['monitorCharts']);
+            if (window.localStorage.monitorCharts) {
+                runtime.charts = $.parseJSON(window.localStorage.monitorCharts);
             }
-            if (window.localStorage['monitorSettings']) {
-                monitorSettings = $.parseJSON(window.localStorage['monitorSettings']);
+            if (window.localStorage.monitorSettings) {
+                monitorSettings = $.parseJSON(window.localStorage.monitorSettings);
             }
 
             $('a[href="#clearMonitorConfig"]').toggle(runtime.charts !== null);
 
-            if (runtime.charts !== null && monitorProtocolVersion != window.localStorage['monitorVersion']) {
+            if (runtime.charts !== null && monitorProtocolVersion != window.localStorage.monitorVersion) {
                 $('#emptyDialog').dialog({title: PMA_messages.strIncompatibleMonitorConfig});
                 $('#emptyDialog').html(PMA_messages.strIncompatibleMonitorConfigDescription);
 
@@ -1079,7 +1084,10 @@ AJAX.registerOnload('server_status_monitor.js', function () {
                     smooth: true
                 },
                 showLine: true,
-                lineWidth: 2
+                lineWidth: 2,
+                markerOptions: {
+                    size: 6
+                }
             },
             highlighter: {
                 show: true
@@ -1147,44 +1155,46 @@ AJAX.registerOnload('server_status_monitor.js', function () {
             series.push([[0, 0]]);
         }
 
+        var tempTooltipContentEditor = function (str, seriesIndex, pointIndex, plot) {
+            var j;
+            // TODO: move style to theme CSS
+            var tooltipHtml = '<div style="font-size:12px;background-color:#FFFFFF;' +
+                'opacity:0.95;filter:alpha(opacity=95);padding:5px;">';
+            // x value i.e. time
+            var timeValue = str.split(",")[0];
+            var seriesValue;
+            tooltipHtml += 'Time: ' + timeValue;
+            tooltipHtml += '<span style="font-weight:bold;">';
+            // Add y values to the tooltip per series
+            for (j in plot.series) {
+                // get y value if present
+                if (plot.series[j].data.length > pointIndex) {
+                    seriesValue = plot.series[j].data[pointIndex][1];
+                } else {
+                    return;
+                }
+                var seriesLabel = plot.series[j].label;
+                var seriesColor = plot.series[j].color;
+                // format y value
+                if (plot.series[0]._yaxis.tickOptions.formatter) {
+                    // using formatter function
+                    seriesValue = plot.series[0]._yaxis.tickOptions.formatter('%s', seriesValue);
+                } else if (plot.series[0]._yaxis.tickOptions.formatString) {
+                    // using format string
+                    seriesValue = PMA_sprintf(plot.series[0]._yaxis.tickOptions.formatString, seriesValue);
+                }
+                tooltipHtml += '<br /><span style="color:' + seriesColor + '">' +
+                    seriesLabel + ': ' + seriesValue + '</span>';
+            }
+            tooltipHtml += '</span></div>';
+            return tooltipHtml;
+        };
+
         // set Tooltip for each series
         for (i in settings.series) {
             settings.series[i].highlighter = {
                 show: true,
-                tooltipContentEditor: function (str, seriesIndex, pointIndex, plot) {
-                    var j;
-                    // TODO: move style to theme CSS
-                    var tooltipHtml = '<div style="font-size:12px;background-color:#FFFFFF;' +
-                        'opacity:0.95;filter:alpha(opacity=95);padding:5px;">';
-                    // x value i.e. time
-                    var timeValue = str.split(",")[0];
-                    var seriesValue;
-                    tooltipHtml += 'Time: ' + timeValue;
-                    tooltipHtml += '<span style="font-weight:bold;">';
-                    // Add y values to the tooltip per series
-                    for (j in plot.series) {
-                        // get y value if present
-                        if (plot.series[j].data.length > pointIndex) {
-                            seriesValue = plot.series[j].data[pointIndex][1];
-                        } else {
-                            return;
-                        }
-                        var seriesLabel = plot.series[j].label;
-                        var seriesColor = plot.series[j].color;
-                        // format y value
-                        if (plot.series[0]._yaxis.tickOptions.formatter) {
-                            // using formatter function
-                            seriesValue = plot.series[0]._yaxis.tickOptions.formatter('%s', seriesValue);
-                        } else if (plot.series[0]._yaxis.tickOptions.formatString) {
-                            // using format string
-                            seriesValue = $.sprintf(plot.series[0]._yaxis.tickOptions.formatString, seriesValue);
-                        }
-                        tooltipHtml += '<br /><span style="color:' + seriesColor + '">' +
-                            seriesLabel + ': ' + seriesValue + '</span>';
-                    }
-                    tooltipHtml += '</span></div>';
-                    return tooltipHtml;
-                }
+                tooltipContentEditor: tempTooltipContentEditor
             };
         }
 
@@ -1343,7 +1353,7 @@ AJAX.registerOnload('server_status_monitor.js', function () {
     /* Called in regular intervalls, this function updates the values of each chart in the grid */
     function refreshChartGrid() {
         /* Send to server */
-        runtime.refreshRequest = $.post('server_status_monitor.php?' + PMA_commonParams.get('common_query'), {
+        runtime.refreshRequest = $.post('server_status_monitor.php' + PMA_commonParams.get('common_query'), {
             ajax_request: true,
             chart_data: 1,
             type: 'chartgrid',
@@ -1448,7 +1458,7 @@ AJAX.registerOnload('server_status_monitor.js', function () {
                 // update chart options
                 // keep ticks number/positioning consistent while refreshrate changes
                 var tickInterval = (runtime.xmax - runtime.xmin) / 5;
-                elem.chart['axes']['xaxis'].ticks = [(runtime.xmax - tickInterval * 4),
+                elem.chart.axes.xaxis.ticks = [(runtime.xmax - tickInterval * 4),
                     (runtime.xmax - tickInterval * 3), (runtime.xmax - tickInterval * 2),
                     (runtime.xmax - tickInterval), runtime.xmax];
 
@@ -1457,13 +1467,13 @@ AJAX.registerOnload('server_status_monitor.js', function () {
                     elem.title !== PMA_messages.strSystemMemory &&
                     elem.title !== PMA_messages.strSystemSwap
                 ) {
-                    elem.chart['axes']['yaxis']['max'] = Math.ceil(elem.maxYLabel * 1.1);
-                    elem.chart['axes']['yaxis']['tickInterval'] = Math.ceil(elem.maxYLabel * 1.1 / 5);
+                    elem.chart.axes.yaxis.max = Math.ceil(elem.maxYLabel * 1.1);
+                    elem.chart.axes.yaxis.tickInterval = Math.ceil(elem.maxYLabel * 1.1 / 5);
                 } else if (elem.title === PMA_messages.strSystemMemory ||
                     elem.title === PMA_messages.strSystemSwap
                 ) {
-                    elem.chart['axes']['yaxis']['max'] = Math.ceil(total * 1.1 / 100) * 100;
-                    elem.chart['axes']['yaxis']['tickInterval'] = Math.ceil(total * 1.1 / 5);
+                    elem.chart.axes.yaxis.max = Math.ceil(total * 1.1 / 100) * 100;
+                    elem.chart.axes.yaxis.tickInterval = Math.ceil(total * 1.1 / 5);
                 }
                 i++;
 
@@ -1582,7 +1592,7 @@ AJAX.registerOnload('server_status_monitor.js', function () {
         });
 
 
-        logRequest = $.get('server_status_monitor.php?' + PMA_commonParams.get('common_query'),
+        logRequest = $.get('server_status_monitor.php' + PMA_commonParams.get('common_query'),
             {   ajax_request: true,
                 log_data: 1,
                 type: opts.src,
@@ -1744,10 +1754,10 @@ AJAX.registerOnload('server_status_monitor.js', function () {
                         $t.next().text(rowData[sumColumnName]);
                         // Restore slow log columns
                         if (isSlowLog) {
-                            $t.parent().children('td:nth-child(3)').text(rowData['query_time']);
-                            $t.parent().children('td:nth-child(4)').text(rowData['lock_time']);
-                            $t.parent().children('td:nth-child(5)').text(rowData['rows_sent']);
-                            $t.parent().children('td:nth-child(6)').text(rowData['rows_examined']);
+                            $t.parent().children('td:nth-child(3)').text(rowData.query_time);
+                            $t.parent().children('td:nth-child(4)').text(rowData.lock_time);
+                            $t.parent().children('td:nth-child(5)').text(rowData.rows_sent);
+                            $t.parent().children('td:nth-child(6)').text(rowData.rows_examined);
                         }
                     }
                 }
@@ -1851,18 +1861,20 @@ AJAX.registerOnload('server_status_monitor.js', function () {
 
         $('#logTable').html($table);
 
+        var tempPushKey = function (key, value) {
+            cols.push(key);
+        };
+
         var formatValue = function (name, value) {
             if (name == 'user_host') {
                 return value.replace(/(\[.*?\])+/g, '');
             }
-            return value;
+            return escapeHtml(value);
         };
 
         for (var i = 0, l = rows.length; i < l; i++) {
             if (i === 0) {
-                $.each(rows[0], function (key, value) {
-                    cols.push(key);
-                });
+                $.each(rows[0], tempPushKey);
                 $table.append('<thead>' +
                               '<tr><th class="nowrap">' + cols.join('</th><th class="nowrap">') + '</th></tr>' +
                               '</thead>'
@@ -1974,7 +1986,7 @@ AJAX.registerOnload('server_status_monitor.js', function () {
             PMA_messages.strAnalyzing + ' <img class="ajaxIcon" src="' +
             pmaThemeImage + 'ajax_clock_small.gif" alt="">');
 
-        $.post('server_status_monitor.php?' + PMA_commonParams.get('common_query'), {
+        $.post('server_status_monitor.php' + PMA_commonParams.get('common_query'), {
             ajax_request: true,
             query_analyzer: true,
             query: codemirror_editor ? codemirror_editor.getValue() : $('#sqlquery').val(),
@@ -1986,7 +1998,7 @@ AJAX.registerOnload('server_status_monitor.js', function () {
             }
             if (data.error) {
                 if (data.error.indexOf('1146') != -1 || data.error.indexOf('1046') != -1) {
-                    data.error = PMA_messages['strServerLogError'];
+                    data.error = PMA_messages.strServerLogError;
                 }
                 $('#queryAnalyzerDialog div.placeHolder').html('<div class="error">' + data.error + '</div>');
                 return;
@@ -2008,19 +2020,22 @@ AJAX.registerOnload('server_status_monitor.js', function () {
                 explain += ')';
             }
             explain += '<p></p>';
+
+            var tempExplain = function (key, value) {
+                value = (value === null) ? 'null' : escapeHtml(value);
+
+                if (key == 'type' && value.toLowerCase() == 'all') {
+                    value = '<span class="attention">' + value + '</span>';
+                }
+                if (key == 'Extra') {
+                    value = value.replace(/(using (temporary|filesort))/gi, '<span class="attention">$1</span>');
+                }
+                explain += key + ': ' + value + '<br />';
+            };
+
             for (i = 0, l = data.explain.length; i < l; i++) {
                 explain += '<div class="explain-' + i + '"' + (i > 0 ?  'style="display:none;"' : '') + '>';
-                $.each(data.explain[i], function (key, value) {
-                    value = (value === null) ? 'null' : value;
-
-                    if (key == 'type' && value.toLowerCase() == 'all') {
-                        value = '<span class="attention">' + value + '</span>';
-                    }
-                    if (key == 'Extra') {
-                        value = value.replace(/(using (temporary|filesort))/gi, '<span class="attention">$1</span>');
-                    }
-                    explain += key + ': ' + value + '<br />';
-                });
+                $.each(data.explain[i], tempExplain);
                 explain += '</div>';
             }
 
@@ -2107,9 +2122,9 @@ AJAX.registerOnload('server_status_monitor.js', function () {
         });
 
         if (window.localStorage) {
-            window.localStorage['monitorCharts'] = JSON.stringify(gridCopy);
-            window.localStorage['monitorSettings'] = JSON.stringify(monitorSettings);
-            window.localStorage['monitorVersion'] = monitorProtocolVersion;
+            window.localStorage.monitorCharts = JSON.stringify(gridCopy);
+            window.localStorage.monitorSettings = JSON.stringify(monitorSettings);
+            window.localStorage.monitorVersion = monitorProtocolVersion;
         }
 
         $('a[href="#clearMonitorConfig"]').show();
