@@ -604,7 +604,9 @@ function PMA_getHtmlForColumnName(
         . (isset($columnMeta['Field'])
             ? htmlspecialchars($columnMeta['Field']) : '')
         . '"' . ' />';
-    if ($cfgRelation['central_columnswork'] && !(isset($columnMeta['column_status'])
+    if (isset($cfgRelation['central_columnswork'])
+        && $cfgRelation['central_columnswork']
+        && !(isset($columnMeta['column_status'])
         && !$columnMeta['column_status']['isEditable'])
     ) {
         $html .=  '<p style="font-size:80%;margin:5px 2px" '
@@ -981,7 +983,7 @@ function PMA_getHtmlForColumnNull($columnNumber, $ci, $ci_offset, $columnMeta)
 function PMA_getHtmlForColumnAttribute($columnNumber, $ci, $ci_offset,
     $extracted_columnspec, $columnMeta, $submit_attribute, $analyzed_sql
 ) {
-    $html = '<select style="font-size: 70%;"'
+    $html = '<select style="width: 7em;"'
         . ' name="field_attribute[' . $columnNumber . ']"'
         . ' id="field_' . $columnNumber . '_' . ($ci - $ci_offset) . '">';
 
